import ast
import numpy as np
import pandas as pd
import matplotlib
matplotlib.use('agg')
import matplotlib.pyplot as plt
from matplotlib.ticker import AutoLocator
import scipy.stats as stats
import math
# font = {'weight' : 'bold',
#         'size'   : 30}
# matplotlib.rc('font', **font)
matplotlib.rcParams['pdf.fonttype'] = 42
matplotlib.rcParams['ps.fonttype'] = 42

def readNEOSresult(file):
	x1 = []
	w1 = []
	with open(file) as f:
	    content = f.readlines()
	xstart=False
	xend=False
	wstart=False
	wend=False
	for x in content:
		if x == ';\n' and xstart==True and xend==False:
			print('xend')
			xend=True
		if x == ';\n' and wstart==True and wend==False:
			print('wend')
			wend=True
		if xstart==True and xend==False:
			x1.append([float(i) for i in x.split()])
		if wstart==True and wend==False:
			w1.append([float(i) for i in x.split()])
		if ':=' in x and xstart==False:
			print('xstart')
			xstart=True
		if ':=' in x and 'y [*] :=' not in x and xend==True and wstart==False:
			print('wstart')
			wstart=True
	x1 = np.array(x1)[:,1:]
	w1 = np.array(w1)[:,1:]
	return (x1, w1)

def pac_man(w,eta,Bx):
	angles = np.linspace(0,2*math.pi,100)
	W = []
	for angle in angles:
		wstar = np.array([10*math.cos(angle),10*math.sin(angle)])
		theta = np.inner(wstar,w)/np.linalg.norm(wstar)
		if np.inner(wstar,w)>0:
			a = min(Bx,1/(2*theta))
		else:
			a = Bx
		x = a*(wstar)/np.linalg.norm(wstar)
		W.append(w + eta*(1-np.inner(x,w))*x)
	return np.vstack(W)


x_DP, w_DP = readNEOSresult('results/RLS_result_eta=0.1.txt')
w_greedy = pd.read_csv('results/w_greedy_eta=0.1.csv',header=None).values;

fig = plt.figure(figsize=(3.25,1.8))

plt.subplot(121)
plt.plot([0]+list(w_DP[:,0]), [1]+list(w_DP[:,1]), '-o', linewidth=1, label = 'NLP, T='+str(14), markersize=3)
# plt.plot([0]+list(w_DP[0::2,1]), [1]+list(w_DP[1::2,1]), '-o', linewidth=2, label = 'NLP, T = '+str(7))
plt.plot(0,1, 'ko', markersize=3, label = '$w_0$')
plt.plot(1,0, 'k*', markersize=6, markeredgewidth=0, label = '$w_{\star}$')
for i in [0]:
	W = pac_man(w_greedy[:,i],0.1,1)
	plt.plot(W[:,0],W[:,1],'-',color = (.8,.8,.8), linewidth=1)
for i in range(2,14,3):
	# W = pac_man(np.array([w_DP[i*2,1],w_DP[i*2+1,1]]),0.4,1)
	plt.plot(w_DP[i,0], w_DP[i,1], 'o',color = 'r', markersize=3)

	W = pac_man(np.array([w_DP[i,0],w_DP[i,1]]),0.1,1)
	plt.plot(W[:,0],W[:,1],'-',color = (.8,.8,.8), linewidth=1)
plt.legend(loc="lower left",fontsize="x-small")   # make legend text smaller
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.axis("equal")
plt.xlim(-0.1, 1.1)
plt.ylim(-0.2, 1.2)
plt.grid()


frame = plt.subplot(122)
frame.axes.yaxis.set_ticklabels([])
plt.plot(w_greedy[0,:], w_greedy[1,:], '-o', linewidth=1, label = 'GREEDY, T='+str(len(w_greedy[0,:])-1), markersize=3)
for i in range(0,21,3):
	plt.plot(w_greedy[0,i], w_greedy[1,i], 'o', color = 'r', markersize=3)
	W = pac_man(w_greedy[:,i],0.1,1)
	plt.plot(W[:,0],W[:,1],'-',color = (.8,.8,.8), linewidth=1)
plt.plot(0,1, 'ko', markersize=3, label = '$w_0$')
plt.plot(1,0, 'k*', markersize=6, markeredgewidth=0, label = '$w_\star$')
plt.legend(loc="upper right",fontsize="x-small")   # make legend text smaller
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.axis("equal")
plt.xlim(-0.1, 1.1)
plt.ylim(-0.2, 1.2)
plt.grid()


plt.tight_layout(pad=0) 
fig.savefig('../figures/pac_man2_no_type3.pdf')
plt.close()




fig = plt.figure(figsize=(8,8))
# plt.xlim(xmax = 2)
# plt.xlim(xmin = -2)
# plt.ylim(ymax = 2)
# plt.ylim(ymin = -2)
plt.grid()
grids = [(i,j) for i in np.linspace(100,110,2) for j in np.linspace(-2,2,2)]
for grid in grids:
	plt.plot(grid[0], grid[1], 'o', color = 'black')
	W = pac_man(np.array(grid),0.1,1)
	plt.plot(W[:,0],W[:,1],'-',color = (.8,.8,.8))
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.tight_layout(pad=0) 
#fig.savefig('pac_man_grid.pdf',bbox_inches='tight')


