import ast
import numpy as np
import pandas as pd
import matplotlib
matplotlib.use('agg')
import matplotlib.pyplot as plt
from matplotlib.ticker import AutoLocator
import scipy.stats as stats
import math
matplotlib.rcParams['pdf.fonttype'] = 42
matplotlib.rcParams['ps.fonttype'] = 42

fig = plt.figure(figsize=(6.7513,2.2))

# Experiment 1: w0 = (0,1)
w0 = [0,1]
w1_CNLP = pd.read_csv('results/w0=(0,1)_CNLP_w.csv',header=None,delimiter='\t').values;
w0_DP = pd.read_csv('results/w0=(0,1)_NLP_w_eta=0.4.csv',header=None,delimiter='\t').values;
w1_DP = pd.read_csv('results/w0=(0,1)_NLP_w_eta=0.02.csv',header=None,delimiter='\t').values;
w2_DP = pd.read_csv('results/w0=(0,1)_NLP_w_eta=0.001.csv',header=None,delimiter='\t').values;

plt.subplot(131)
plt.grid()
plt.plot(w0[0],w0[1], 'ko', markersize=3, label = '', zorder=10)
plt.plot(1,0, 'k*',markersize=6, markeredgewidth=0, label = '', zorder=10)
plt.plot(w1_CNLP[:,0], w1_CNLP[:,1], '-', linewidth=2, label = 'CNLP, $t_f$ =1.52s', color=(.8,.8,.8))
plt.plot(w0_DP[0,:], w0_DP[1,:], '-o', linewidth=1, markersize=3, label = 'NLP, $\eta$=0.4, T='+str(len(w0_DP[0,:])-1))
plt.plot(w1_DP[0,:], w1_DP[1,:], '-', linewidth=1.5, label = 'NLP, $\eta$=0.02, T='+str(len(w1_DP[0,:])-1))
plt.plot(w2_DP[0,:], w2_DP[1,:], '--', linewidth=1, label = 'NLP, $\eta$=0.001, T='+str(len(w2_DP[0,:])-1))
plt.legend(loc="lower left",fontsize="x-small")   # make legend text smaller
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.axis("equal")
plt.xlim(xmax = 1.5)
plt.xlim(xmin = -0.5)
plt.ylim(ymax = 1.1)
plt.ylim(ymin = -0.1)


# Experiment 2: w0 = (0,2.5)
w0 = [0,2.5]
w1_CNLP = pd.read_csv('results/w0=(0,2.5)_CNLP_w.csv',header=None,delimiter='\t').values;
w0_DP = pd.read_csv('results/w0=(0,2.5)_NLP_w_eta=0.4.csv',header=None,delimiter='\t').values;
w1_DP = pd.read_csv('results/w0=(0,2.5)_NLP_w_eta=0.02.csv',header=None,delimiter='\t').values;
w2_DP = pd.read_csv('results/w0=(0,2.5)_NLP_w_eta=0.001.csv',header=None,delimiter='\t').values;

plt.subplot(132)

plt.grid()
plt.plot(w0[0],w0[1], 'ko', markersize=3, label = '$w_0$', zorder=10)
plt.plot(1,0, 'k*',markersize=6, markeredgewidth=0, label = '$w_\star$', zorder=10)
plt.plot(w1_CNLP[:,0], w1_CNLP[:,1], '-', linewidth=2, label = 'CNLP, $t_f$ =1.53s', color=(.8,.8,.8))
plt.plot(w0_DP[0,:], w0_DP[1,:], '-o', linewidth=1, markersize=3, label = 'NLP, $\eta$=0.4, T='+str(len(w0_DP[0,:])-1))
plt.plot(w1_DP[0,:], w1_DP[1,:], '-', linewidth=1.5, label = 'NLP, $\eta$=0.02, T='+str(len(w1_DP[0,:])-1))
plt.plot(w2_DP[0,:], w2_DP[1,:], '--', linewidth=1, label = 'NLP, $\eta$=0.001, T='+str(len(w2_DP[0,:])-1))
plt.legend(loc="lower left",fontsize="x-small")   # make legend text smaller
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.axis("equal")
plt.xlim(xmax = 1.2)
plt.xlim(xmin = -1.5)
plt.ylim(ymax = 2.6)
plt.ylim(ymin = -0.1)


# Experiment 3: w0 = (-1.5,0.5)
w0 = [-1.5,0.5]
w1_CNLP = pd.read_csv('results/w0=(-1.5,0.5)_CNLP_w.csv',header=None,delimiter='\t').values;
w0_DP = pd.read_csv('results/w0=(-1.5,0.5)_NLP_w_eta=0.4.csv',header=None,delimiter='\t').values;
w1_DP = pd.read_csv('results/w0=(-1.5,0.5)_NLP_w_eta=0.02.csv',header=None,delimiter='\t').values;
w2_DP = pd.read_csv('results/w0=(-1.5,0.5)_NLP_w_eta=0.001.csv',header=None,delimiter='\t').values;

plt.subplot(133)

plt.grid()
plt.plot(w0[0],w0[1], 'ko', markersize=3, label = '', zorder=10)
plt.plot(1,0, 'k*',markersize=6, markeredgewidth=0, label = '', zorder=10)
plt.plot(w1_CNLP[:,0], w1_CNLP[:,1], '-', linewidth=2, label = 'CNLP, $t_f$ =2.59s', color=(.8,.8,.8))
plt.plot(w0_DP[0,:], w0_DP[1,:], '-o', linewidth=1, markersize=3, label = 'NLP, $\eta$=0.4, T='+str(len(w0_DP[0,:])-1))
plt.plot(w1_DP[0,:], w1_DP[1,:], '-', linewidth=1.5, label = 'NLP, $\eta$=0.02, T='+str(len(w1_DP[0,:])-1))
plt.plot(w2_DP[0,:], w2_DP[1,:], '--', linewidth=1, label = 'NLP, $\eta$=0.001, T='+str(len(w2_DP[0,:])-1))
plt.legend(loc="lower left",fontsize="x-small")   # make legend text smaller
plt.xticks(fontsize=6)
plt.yticks(fontsize=6)
plt.axis("equal")
plt.xlim(xmax = 1.1)
plt.xlim(xmin = -1.6)
plt.ylim(ymax = 1.6)
plt.ylim(ymin = -1.1)

plt.tight_layout(pad=0)

fig.savefig('../figures/convergence_combined_no_type3.pdf')
plt.close()
